==> arith-utils_1.0.20131222.tar.gz: arith-utils/add.f <==
*     JLdL 03Apr07.
*     
*     Copyright (C) 2007 by Jorge L. deLyra.
*     Mail: <delyra@latt.if.usp.br>. Web: "http://latt.if.usp.br".
*     This program may be copied and/or distributed freely. See the
*     _ terms and conditions in the files in the doc/ subdirectory.
*     
*     This program reads a sequence of numbers from stdin, then
*     _ calculates their sum and writes it to stdout.
*     
      PROGRAM ADD
*     
*     Double precision everything.
      implicit double precision (a-h,o-z)
*     
*     The maximum number of numbers that this
*     _ program can deal with, plus one.
      parameter(nmax=10001)
*     
*     Storage for the numbers, in real form.
      dimension rnum(nmax)
*     
*     Read the numbers from stdin; this can be any combination
*     _ of rows and columns of integer or real numbers.
      read(*,*,iostat=ioerr) (rnum(inum),inum=1,nmax)
*     
*     There must have been an end-of-file read error.
      if (ioerr.ne.-1) then
*     
*     Write an error message and abort.
         if (ioerr.eq.0) then
            write(*,*) 'add: ERROR: too many numbers'
         else
            write(*,*) 'add: ERROR: input read error'
         end if
*     
         stop
*     
      end if
*     
*     Determine the number of numbers read in.
      nnum=inum-1
*     
*     Add all the numbers.
      sum=0.0d0
      do inum=1,nnum
         sum=sum+rnum(inum)
      end do
*     
*     If the number is an integer, write it out as such;
*     _ otherwise, write it out as a real number.
      num=int(sum)
      if (dble(num).eq.sum) then
         write(*,*) num
      else
         write(*,*) sum
      end if
*     
      END

==> arith-utils_1.0.20140130.tar.gz: arith-utils/add.f <==
*     JLdL 30Jan14.
*     
*     Copyright (C) 2007-2014 by Jorge L. deLyra.
*     Mail: <delyra@latt.if.usp.br>. Web: "http://latt.if.usp.br".
*     This program may be copied and/or distributed freely. See the
*     _ terms and conditions in the files in the doc/ subdirectory.
*     
*     This program reads a sequence of numbers from stdin, then
*     _ calculates their sum and writes it to stdout.
*     
      PROGRAM ADD
*     
*     Double precision everything.
      implicit double precision (a-h,o-z)
*     
*     The maximum number of numbers that this
*     _ program can deal with, plus one.
      parameter(nmax=10001)
*     
*     Storage for the numbers, in real form.
      dimension rnum(nmax)
*     
*     Read the numbers from stdin; this must be a single
*     _ column of single integer or real numbers.
      do inum=1,nmax
         read(*,*,iostat=ioerr) rnum(inum)
         if (ioerr.ne.0) exit
      end do
*     
*     There must have been an end-of-file read error.
      if (ioerr.ne.-1) then
*     
*     Write an error message and abort.
         if (ioerr.eq.0) then
            write(*,*) 'add: ERROR: too many numbers'
         else
            write(*,*) 'add: ERROR: input read error'
         end if
*     
         stop
*     
      end if
*     
*     Determine the number of numbers read in.
      nnum=inum-1
*     
*     Add all the numbers.
      sum=0.0d0
      do inum=1,nnum
         sum=sum+rnum(inum)
      end do
*     
*     If the number is an integer, write it out as such;
*     _ otherwise, write it out as a real number.
      num=int(sum)
      if (dble(num).eq.sum) then
         write(*,*) num
      else
         write(*,*) sum
      end if
*     
      END
